"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from documenso_sdk.utils import FieldMetadata, PathParamMetadata
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import Any, Dict, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class DocumentGetRequestTypedDict(TypedDict):
    document_id: float


class DocumentGetRequest(BaseModel):
    document_id: Annotated[
        float,
        pydantic.Field(alias="documentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class DocumentGetInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class DocumentGetInternalServerErrorIssue(BaseModel):
    message: str


class DocumentGetInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentGetInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentGetInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: DocumentGetInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentGetInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentGetNotFoundIssueTypedDict(TypedDict):
    message: str


class DocumentGetNotFoundIssue(BaseModel):
    message: str


class DocumentGetNotFoundErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentGetNotFoundIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentGetNotFoundError(DocumensoError):
    r"""Not found"""

    data: DocumentGetNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentGetNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentGetForbiddenIssueTypedDict(TypedDict):
    message: str


class DocumentGetForbiddenIssue(BaseModel):
    message: str


class DocumentGetForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentGetForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentGetForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: DocumentGetForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentGetForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentGetUnauthorizedIssueTypedDict(TypedDict):
    message: str


class DocumentGetUnauthorizedIssue(BaseModel):
    message: str


class DocumentGetUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentGetUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentGetUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: DocumentGetUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentGetUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentGetBadRequestIssueTypedDict(TypedDict):
    message: str


class DocumentGetBadRequestIssue(BaseModel):
    message: str


class DocumentGetBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentGetBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentGetBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: DocumentGetBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentGetBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentGetVisibility(str, Enum):
    EVERYONE = "EVERYONE"
    MANAGER_AND_ABOVE = "MANAGER_AND_ABOVE"
    ADMIN = "ADMIN"


class DocumentGetStatus(str, Enum):
    DRAFT = "DRAFT"
    PENDING = "PENDING"
    COMPLETED = "COMPLETED"
    REJECTED = "REJECTED"


class DocumentGetSource(str, Enum):
    DOCUMENT = "DOCUMENT"
    TEMPLATE = "TEMPLATE"
    TEMPLATE_DIRECT_LINK = "TEMPLATE_DIRECT_LINK"


class DocumentGetGlobalAccessAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class DocumentGetGlobalActionAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"


class DocumentGetAuthOptionsTypedDict(TypedDict):
    global_access_auth: List[DocumentGetGlobalAccessAuth]
    global_action_auth: List[DocumentGetGlobalActionAuth]


class DocumentGetAuthOptions(BaseModel):
    global_access_auth: Annotated[
        List[DocumentGetGlobalAccessAuth], pydantic.Field(alias="globalAccessAuth")
    ]

    global_action_auth: Annotated[
        List[DocumentGetGlobalActionAuth], pydantic.Field(alias="globalActionAuth")
    ]


DocumentGetFormValuesTypedDict = TypeAliasType(
    "DocumentGetFormValuesTypedDict", Union[str, bool, float]
)


DocumentGetFormValues = TypeAliasType("DocumentGetFormValues", Union[str, bool, float])


class DocumentGetDocumentDataType(str, Enum):
    S3_PATH = "S3_PATH"
    BYTES = "BYTES"
    BYTES_64 = "BYTES_64"


class DocumentGetDocumentDataTypedDict(TypedDict):
    type: DocumentGetDocumentDataType
    id: str
    data: str
    initial_data: str
    envelope_item_id: str


class DocumentGetDocumentData(BaseModel):
    type: DocumentGetDocumentDataType

    id: str

    data: str

    initial_data: Annotated[str, pydantic.Field(alias="initialData")]

    envelope_item_id: Annotated[str, pydantic.Field(alias="envelopeItemId")]


class DocumentGetSigningOrder(str, Enum):
    PARALLEL = "PARALLEL"
    SEQUENTIAL = "SEQUENTIAL"


class DocumentGetDistributionMethod(str, Enum):
    EMAIL = "EMAIL"
    NONE = "NONE"


class DocumentGetEmailSettingsTypedDict(TypedDict):
    recipient_signing_request: NotRequired[bool]
    recipient_removed: NotRequired[bool]
    recipient_signed: NotRequired[bool]
    document_pending: NotRequired[bool]
    document_completed: NotRequired[bool]
    document_deleted: NotRequired[bool]
    owner_document_completed: NotRequired[bool]


class DocumentGetEmailSettings(BaseModel):
    recipient_signing_request: Annotated[
        Optional[bool], pydantic.Field(alias="recipientSigningRequest")
    ] = True

    recipient_removed: Annotated[
        Optional[bool], pydantic.Field(alias="recipientRemoved")
    ] = True

    recipient_signed: Annotated[
        Optional[bool], pydantic.Field(alias="recipientSigned")
    ] = True

    document_pending: Annotated[
        Optional[bool], pydantic.Field(alias="documentPending")
    ] = True

    document_completed: Annotated[
        Optional[bool], pydantic.Field(alias="documentCompleted")
    ] = True

    document_deleted: Annotated[
        Optional[bool], pydantic.Field(alias="documentDeleted")
    ] = True

    owner_document_completed: Annotated[
        Optional[bool], pydantic.Field(alias="ownerDocumentCompleted")
    ] = True


class DocumentGetDocumentMetaTypedDict(TypedDict):
    signing_order: DocumentGetSigningOrder
    distribution_method: DocumentGetDistributionMethod
    id: str
    subject: Nullable[str]
    message: Nullable[str]
    timezone: Nullable[str]
    date_format: Nullable[str]
    redirect_url: Nullable[str]
    typed_signature_enabled: bool
    upload_signature_enabled: bool
    draw_signature_enabled: bool
    allow_dictate_next_signer: bool
    language: str
    email_settings: Nullable[DocumentGetEmailSettingsTypedDict]
    email_id: Nullable[str]
    email_reply_to: Nullable[str]
    password: NotRequired[Nullable[str]]
    document_id: NotRequired[float]


class DocumentGetDocumentMeta(BaseModel):
    signing_order: Annotated[
        DocumentGetSigningOrder, pydantic.Field(alias="signingOrder")
    ]

    distribution_method: Annotated[
        DocumentGetDistributionMethod, pydantic.Field(alias="distributionMethod")
    ]

    id: str

    subject: Nullable[str]

    message: Nullable[str]

    timezone: Nullable[str]

    date_format: Annotated[Nullable[str], pydantic.Field(alias="dateFormat")]

    redirect_url: Annotated[Nullable[str], pydantic.Field(alias="redirectUrl")]

    typed_signature_enabled: Annotated[
        bool, pydantic.Field(alias="typedSignatureEnabled")
    ]

    upload_signature_enabled: Annotated[
        bool, pydantic.Field(alias="uploadSignatureEnabled")
    ]

    draw_signature_enabled: Annotated[
        bool, pydantic.Field(alias="drawSignatureEnabled")
    ]

    allow_dictate_next_signer: Annotated[
        bool, pydantic.Field(alias="allowDictateNextSigner")
    ]

    language: str

    email_settings: Annotated[
        Nullable[DocumentGetEmailSettings], pydantic.Field(alias="emailSettings")
    ]

    email_id: Annotated[Nullable[str], pydantic.Field(alias="emailId")]

    email_reply_to: Annotated[Nullable[str], pydantic.Field(alias="emailReplyTo")]

    password: OptionalNullable[str] = None

    document_id: Annotated[Optional[float], pydantic.Field(alias="documentId")] = -1

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["password", "documentId"]
        nullable_fields = [
            "subject",
            "message",
            "timezone",
            "dateFormat",
            "redirectUrl",
            "emailSettings",
            "emailId",
            "emailReplyTo",
            "password",
        ]
        null_default_fields = ["password"]

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class DocumentGetEnvelopeItemTypedDict(TypedDict):
    id: str
    envelope_id: str


class DocumentGetEnvelopeItem(BaseModel):
    id: str

    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]


class DocumentGetFolderType(str, Enum):
    DOCUMENT = "DOCUMENT"
    TEMPLATE = "TEMPLATE"


class DocumentGetFolderVisibility(str, Enum):
    EVERYONE = "EVERYONE"
    MANAGER_AND_ABOVE = "MANAGER_AND_ABOVE"
    ADMIN = "ADMIN"


class DocumentGetFolderTypedDict(TypedDict):
    id: str
    name: str
    type: DocumentGetFolderType
    visibility: DocumentGetFolderVisibility
    user_id: float
    team_id: float
    pinned: bool
    parent_id: Nullable[str]
    created_at: str
    updated_at: str


class DocumentGetFolder(BaseModel):
    id: str

    name: str

    type: DocumentGetFolderType

    visibility: DocumentGetFolderVisibility

    user_id: Annotated[float, pydantic.Field(alias="userId")]

    team_id: Annotated[float, pydantic.Field(alias="teamId")]

    pinned: bool

    parent_id: Annotated[Nullable[str], pydantic.Field(alias="parentId")]

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]

    updated_at: Annotated[str, pydantic.Field(alias="updatedAt")]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["parentId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class DocumentGetRole(str, Enum):
    CC = "CC"
    SIGNER = "SIGNER"
    VIEWER = "VIEWER"
    APPROVER = "APPROVER"
    ASSISTANT = "ASSISTANT"


class DocumentGetReadStatus(str, Enum):
    NOT_OPENED = "NOT_OPENED"
    OPENED = "OPENED"


class DocumentGetSigningStatus(str, Enum):
    NOT_SIGNED = "NOT_SIGNED"
    SIGNED = "SIGNED"
    REJECTED = "REJECTED"


class DocumentGetSendStatus(str, Enum):
    NOT_SENT = "NOT_SENT"
    SENT = "SENT"


class DocumentGetAccessAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class DocumentGetActionAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"
    EXPLICIT_NONE = "EXPLICIT_NONE"


class DocumentGetRecipientAuthOptionsTypedDict(TypedDict):
    access_auth: List[DocumentGetAccessAuth]
    action_auth: List[DocumentGetActionAuth]


class DocumentGetRecipientAuthOptions(BaseModel):
    access_auth: Annotated[
        List[DocumentGetAccessAuth], pydantic.Field(alias="accessAuth")
    ]

    action_auth: Annotated[
        List[DocumentGetActionAuth], pydantic.Field(alias="actionAuth")
    ]


class DocumentGetRecipientTypedDict(TypedDict):
    envelope_id: str
    role: DocumentGetRole
    read_status: DocumentGetReadStatus
    signing_status: DocumentGetSigningStatus
    send_status: DocumentGetSendStatus
    id: float
    email: str
    name: str
    token: str
    document_deleted_at: Nullable[str]
    expired: Nullable[str]
    signed_at: Nullable[str]
    auth_options: Nullable[DocumentGetRecipientAuthOptionsTypedDict]
    signing_order: Nullable[float]
    rejection_reason: Nullable[str]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class DocumentGetRecipient(BaseModel):
    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    role: DocumentGetRole

    read_status: Annotated[DocumentGetReadStatus, pydantic.Field(alias="readStatus")]

    signing_status: Annotated[
        DocumentGetSigningStatus, pydantic.Field(alias="signingStatus")
    ]

    send_status: Annotated[DocumentGetSendStatus, pydantic.Field(alias="sendStatus")]

    id: float

    email: str

    name: str

    token: str

    document_deleted_at: Annotated[
        Nullable[str], pydantic.Field(alias="documentDeletedAt")
    ]

    expired: Nullable[str]

    signed_at: Annotated[Nullable[str], pydantic.Field(alias="signedAt")]

    auth_options: Annotated[
        Nullable[DocumentGetRecipientAuthOptions], pydantic.Field(alias="authOptions")
    ]

    signing_order: Annotated[Nullable[float], pydantic.Field(alias="signingOrder")]

    rejection_reason: Annotated[Nullable[str], pydantic.Field(alias="rejectionReason")]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = [
            "documentDeletedAt",
            "expired",
            "signedAt",
            "authOptions",
            "signingOrder",
            "rejectionReason",
            "documentId",
            "templateId",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class DocumentGetFieldType(str, Enum):
    SIGNATURE = "SIGNATURE"
    FREE_SIGNATURE = "FREE_SIGNATURE"
    INITIALS = "INITIALS"
    NAME = "NAME"
    EMAIL = "EMAIL"
    DATE = "DATE"
    TEXT = "TEXT"
    NUMBER = "NUMBER"
    RADIO = "RADIO"
    CHECKBOX = "CHECKBOX"
    DROPDOWN = "DROPDOWN"


class DocumentGetTypeDropdown(str, Enum):
    DROPDOWN = "dropdown"


class DocumentGetValue3TypedDict(TypedDict):
    value: str


class DocumentGetValue3(BaseModel):
    value: str


class DocumentGetFieldMetaDropdownTypedDict(TypedDict):
    type: DocumentGetTypeDropdown
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[DocumentGetValue3TypedDict]]
    default_value: NotRequired[str]


class DocumentGetFieldMetaDropdown(BaseModel):
    type: DocumentGetTypeDropdown

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[DocumentGetValue3]] = None

    default_value: Annotated[Optional[str], pydantic.Field(alias="defaultValue")] = None


class DocumentGetTypeCheckbox(str, Enum):
    CHECKBOX = "checkbox"


class DocumentGetValue2TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class DocumentGetValue2(BaseModel):
    id: float

    checked: bool

    value: str


class DocumentGetDirection2(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class DocumentGetFieldMetaCheckboxTypedDict(TypedDict):
    type: DocumentGetTypeCheckbox
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[DocumentGetValue2TypedDict]]
    validation_rule: NotRequired[str]
    validation_length: NotRequired[float]
    direction: NotRequired[DocumentGetDirection2]


class DocumentGetFieldMetaCheckbox(BaseModel):
    type: DocumentGetTypeCheckbox

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[DocumentGetValue2]] = None

    validation_rule: Annotated[
        Optional[str], pydantic.Field(alias="validationRule")
    ] = None

    validation_length: Annotated[
        Optional[float], pydantic.Field(alias="validationLength")
    ] = None

    direction: Optional[DocumentGetDirection2] = DocumentGetDirection2.VERTICAL


class DocumentGetTypeRadio(str, Enum):
    RADIO = "radio"


class DocumentGetValue1TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class DocumentGetValue1(BaseModel):
    id: float

    checked: bool

    value: str


class DocumentGetDirection1(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class DocumentGetFieldMetaRadioTypedDict(TypedDict):
    type: DocumentGetTypeRadio
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[DocumentGetValue1TypedDict]]
    direction: NotRequired[DocumentGetDirection1]


class DocumentGetFieldMetaRadio(BaseModel):
    type: DocumentGetTypeRadio

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[DocumentGetValue1]] = None

    direction: Optional[DocumentGetDirection1] = DocumentGetDirection1.VERTICAL


class DocumentGetTypeNumber(str, Enum):
    NUMBER = "number"


class DocumentGetTextAlign6(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class DocumentGetVerticalAlign2(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class DocumentGetFieldMetaNumberTypedDict(TypedDict):
    type: DocumentGetTypeNumber
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    number_format: NotRequired[Nullable[str]]
    value: NotRequired[str]
    min_value: NotRequired[Nullable[float]]
    max_value: NotRequired[Nullable[float]]
    text_align: NotRequired[DocumentGetTextAlign6]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[DocumentGetVerticalAlign2]]


class DocumentGetFieldMetaNumber(BaseModel):
    type: DocumentGetTypeNumber

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    number_format: Annotated[
        OptionalNullable[str], pydantic.Field(alias="numberFormat")
    ] = UNSET

    value: Optional[str] = None

    min_value: Annotated[OptionalNullable[float], pydantic.Field(alias="minValue")] = (
        UNSET
    )

    max_value: Annotated[OptionalNullable[float], pydantic.Field(alias="maxValue")] = (
        UNSET
    )

    text_align: Annotated[
        Optional[DocumentGetTextAlign6], pydantic.Field(alias="textAlign")
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[DocumentGetVerticalAlign2],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "numberFormat",
            "value",
            "minValue",
            "maxValue",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = [
            "numberFormat",
            "minValue",
            "maxValue",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class DocumentGetTypeText(str, Enum):
    TEXT = "text"


class DocumentGetTextAlign5(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class DocumentGetVerticalAlign1(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class DocumentGetFieldMetaTextTypedDict(TypedDict):
    type: DocumentGetTypeText
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text: NotRequired[str]
    character_limit: NotRequired[float]
    text_align: NotRequired[DocumentGetTextAlign5]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[DocumentGetVerticalAlign1]]


class DocumentGetFieldMetaText(BaseModel):
    type: DocumentGetTypeText

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text: Optional[str] = None

    character_limit: Annotated[
        Optional[float], pydantic.Field(alias="characterLimit")
    ] = None

    text_align: Annotated[
        Optional[DocumentGetTextAlign5], pydantic.Field(alias="textAlign")
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[DocumentGetVerticalAlign1],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "text",
            "characterLimit",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = ["lineHeight", "letterSpacing", "verticalAlign"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class DocumentGetTypeDate(str, Enum):
    DATE = "date"


class DocumentGetTextAlign4(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class DocumentGetFieldMetaDateTypedDict(TypedDict):
    type: DocumentGetTypeDate
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[DocumentGetTextAlign4]


class DocumentGetFieldMetaDate(BaseModel):
    type: DocumentGetTypeDate

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[DocumentGetTextAlign4], pydantic.Field(alias="textAlign")
    ] = None


class DocumentGetTypeEmail(str, Enum):
    EMAIL = "email"


class DocumentGetTextAlign3(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class DocumentGetFieldMetaEmailTypedDict(TypedDict):
    type: DocumentGetTypeEmail
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[DocumentGetTextAlign3]


class DocumentGetFieldMetaEmail(BaseModel):
    type: DocumentGetTypeEmail

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[DocumentGetTextAlign3], pydantic.Field(alias="textAlign")
    ] = None


class DocumentGetTypeName(str, Enum):
    NAME = "name"


class DocumentGetTextAlign2(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class DocumentGetFieldMetaNameTypedDict(TypedDict):
    type: DocumentGetTypeName
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[DocumentGetTextAlign2]


class DocumentGetFieldMetaName(BaseModel):
    type: DocumentGetTypeName

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[DocumentGetTextAlign2], pydantic.Field(alias="textAlign")
    ] = None


class DocumentGetTypeInitials(str, Enum):
    INITIALS = "initials"


class DocumentGetTextAlign1(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class DocumentGetFieldMetaInitialsTypedDict(TypedDict):
    type: DocumentGetTypeInitials
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[DocumentGetTextAlign1]


class DocumentGetFieldMetaInitials(BaseModel):
    type: DocumentGetTypeInitials

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[DocumentGetTextAlign1], pydantic.Field(alias="textAlign")
    ] = None


class DocumentGetTypeSignature(str, Enum):
    SIGNATURE = "signature"


class DocumentGetFieldMetaSignatureTypedDict(TypedDict):
    type: DocumentGetTypeSignature
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]


class DocumentGetFieldMetaSignature(BaseModel):
    type: DocumentGetTypeSignature

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12


DocumentGetFieldMetaUnionTypedDict = TypeAliasType(
    "DocumentGetFieldMetaUnionTypedDict",
    Union[
        DocumentGetFieldMetaSignatureTypedDict,
        DocumentGetFieldMetaInitialsTypedDict,
        DocumentGetFieldMetaNameTypedDict,
        DocumentGetFieldMetaEmailTypedDict,
        DocumentGetFieldMetaDateTypedDict,
        DocumentGetFieldMetaRadioTypedDict,
        DocumentGetFieldMetaDropdownTypedDict,
        DocumentGetFieldMetaCheckboxTypedDict,
        DocumentGetFieldMetaTextTypedDict,
        DocumentGetFieldMetaNumberTypedDict,
    ],
)


DocumentGetFieldMetaUnion = TypeAliasType(
    "DocumentGetFieldMetaUnion",
    Union[
        DocumentGetFieldMetaSignature,
        DocumentGetFieldMetaInitials,
        DocumentGetFieldMetaName,
        DocumentGetFieldMetaEmail,
        DocumentGetFieldMetaDate,
        DocumentGetFieldMetaRadio,
        DocumentGetFieldMetaDropdown,
        DocumentGetFieldMetaCheckbox,
        DocumentGetFieldMetaText,
        DocumentGetFieldMetaNumber,
    ],
)


class DocumentGetFieldTypedDict(TypedDict):
    envelope_id: str
    envelope_item_id: str
    type: DocumentGetFieldType
    id: float
    secondary_id: str
    recipient_id: float
    page: float
    position_x: Any
    position_y: Any
    width: Any
    height: Any
    custom_text: str
    inserted: bool
    field_meta: Nullable[DocumentGetFieldMetaUnionTypedDict]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class DocumentGetField(BaseModel):
    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    envelope_item_id: Annotated[str, pydantic.Field(alias="envelopeItemId")]

    type: DocumentGetFieldType

    id: float

    secondary_id: Annotated[str, pydantic.Field(alias="secondaryId")]

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page: float

    position_x: Annotated[Any, pydantic.Field(alias="positionX")]

    position_y: Annotated[Any, pydantic.Field(alias="positionY")]

    width: Any

    height: Any

    custom_text: Annotated[str, pydantic.Field(alias="customText")]

    inserted: bool

    field_meta: Annotated[
        Nullable[DocumentGetFieldMetaUnion], pydantic.Field(alias="fieldMeta")
    ]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = ["fieldMeta", "documentId", "templateId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class DocumentGetResponseTypedDict(TypedDict):
    r"""Successful response"""

    visibility: DocumentGetVisibility
    status: DocumentGetStatus
    source: DocumentGetSource
    id: float
    external_id: Nullable[str]
    user_id: float
    auth_options: Nullable[DocumentGetAuthOptionsTypedDict]
    form_values: Nullable[Dict[str, DocumentGetFormValuesTypedDict]]
    title: str
    created_at: str
    updated_at: str
    completed_at: Nullable[str]
    deleted_at: Nullable[str]
    team_id: float
    folder_id: Nullable[str]
    envelope_id: str
    internal_version: float
    document_data: DocumentGetDocumentDataTypedDict
    document_meta: DocumentGetDocumentMetaTypedDict
    envelope_items: List[DocumentGetEnvelopeItemTypedDict]
    folder: Nullable[DocumentGetFolderTypedDict]
    recipients: List[DocumentGetRecipientTypedDict]
    fields: List[DocumentGetFieldTypedDict]
    template_id: NotRequired[Nullable[float]]
    document_data_id: NotRequired[str]


class DocumentGetResponse(BaseModel):
    r"""Successful response"""

    visibility: DocumentGetVisibility

    status: DocumentGetStatus

    source: DocumentGetSource

    id: float

    external_id: Annotated[Nullable[str], pydantic.Field(alias="externalId")]

    user_id: Annotated[float, pydantic.Field(alias="userId")]

    auth_options: Annotated[
        Nullable[DocumentGetAuthOptions], pydantic.Field(alias="authOptions")
    ]

    form_values: Annotated[
        Nullable[Dict[str, DocumentGetFormValues]], pydantic.Field(alias="formValues")
    ]

    title: str

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]

    updated_at: Annotated[str, pydantic.Field(alias="updatedAt")]

    completed_at: Annotated[Nullable[str], pydantic.Field(alias="completedAt")]

    deleted_at: Annotated[Nullable[str], pydantic.Field(alias="deletedAt")]

    team_id: Annotated[float, pydantic.Field(alias="teamId")]

    folder_id: Annotated[Nullable[str], pydantic.Field(alias="folderId")]

    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    internal_version: Annotated[float, pydantic.Field(alias="internalVersion")]

    document_data: Annotated[
        DocumentGetDocumentData, pydantic.Field(alias="documentData")
    ]

    document_meta: Annotated[
        DocumentGetDocumentMeta, pydantic.Field(alias="documentMeta")
    ]

    envelope_items: Annotated[
        List[DocumentGetEnvelopeItem], pydantic.Field(alias="envelopeItems")
    ]

    folder: Nullable[DocumentGetFolder]

    recipients: List[DocumentGetRecipient]

    fields: List[DocumentGetField]

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    document_data_id: Annotated[
        Optional[str], pydantic.Field(alias="documentDataId")
    ] = ""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["templateId", "documentDataId"]
        nullable_fields = [
            "externalId",
            "authOptions",
            "formValues",
            "completedAt",
            "deletedAt",
            "folderId",
            "templateId",
            "folder",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel
import httpx
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, TypedDict


class RecipientDeleteDocumentRecipientRequestTypedDict(TypedDict):
    recipient_id: float


class RecipientDeleteDocumentRecipientRequest(BaseModel):
    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]


class RecipientDeleteDocumentRecipientInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class RecipientDeleteDocumentRecipientInternalServerErrorIssue(BaseModel):
    message: str


class RecipientDeleteDocumentRecipientInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientDeleteDocumentRecipientInternalServerErrorIssue]] = (
        None
    )


@dataclass(unsafe_hash=True)
class RecipientDeleteDocumentRecipientInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: RecipientDeleteDocumentRecipientInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientDeleteDocumentRecipientInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientDeleteDocumentRecipientForbiddenIssueTypedDict(TypedDict):
    message: str


class RecipientDeleteDocumentRecipientForbiddenIssue(BaseModel):
    message: str


class RecipientDeleteDocumentRecipientForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientDeleteDocumentRecipientForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientDeleteDocumentRecipientForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: RecipientDeleteDocumentRecipientForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientDeleteDocumentRecipientForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientDeleteDocumentRecipientUnauthorizedIssueTypedDict(TypedDict):
    message: str


class RecipientDeleteDocumentRecipientUnauthorizedIssue(BaseModel):
    message: str


class RecipientDeleteDocumentRecipientUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientDeleteDocumentRecipientUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientDeleteDocumentRecipientUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: RecipientDeleteDocumentRecipientUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientDeleteDocumentRecipientUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientDeleteDocumentRecipientBadRequestIssueTypedDict(TypedDict):
    message: str


class RecipientDeleteDocumentRecipientBadRequestIssue(BaseModel):
    message: str


class RecipientDeleteDocumentRecipientBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientDeleteDocumentRecipientBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientDeleteDocumentRecipientBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: RecipientDeleteDocumentRecipientBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientDeleteDocumentRecipientBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientDeleteDocumentRecipientResponseTypedDict(TypedDict):
    r"""Successful response"""

    success: bool


class RecipientDeleteDocumentRecipientResponse(BaseModel):
    r"""Successful response"""

    success: bool



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel
import httpx
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, TypedDict


class DocumentAttachmentCreateDataTypedDict(TypedDict):
    label: str
    data: str


class DocumentAttachmentCreateData(BaseModel):
    label: str

    data: str


class DocumentAttachmentCreateRequestTypedDict(TypedDict):
    document_id: float
    data: DocumentAttachmentCreateDataTypedDict


class DocumentAttachmentCreateRequest(BaseModel):
    document_id: Annotated[float, pydantic.Field(alias="documentId")]

    data: DocumentAttachmentCreateData


class DocumentAttachmentCreateInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class DocumentAttachmentCreateInternalServerErrorIssue(BaseModel):
    message: str


class DocumentAttachmentCreateInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentAttachmentCreateInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentAttachmentCreateInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: DocumentAttachmentCreateInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentAttachmentCreateInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentAttachmentCreateForbiddenIssueTypedDict(TypedDict):
    message: str


class DocumentAttachmentCreateForbiddenIssue(BaseModel):
    message: str


class DocumentAttachmentCreateForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentAttachmentCreateForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentAttachmentCreateForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: DocumentAttachmentCreateForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentAttachmentCreateForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentAttachmentCreateUnauthorizedIssueTypedDict(TypedDict):
    message: str


class DocumentAttachmentCreateUnauthorizedIssue(BaseModel):
    message: str


class DocumentAttachmentCreateUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentAttachmentCreateUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentAttachmentCreateUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: DocumentAttachmentCreateUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentAttachmentCreateUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentAttachmentCreateBadRequestIssueTypedDict(TypedDict):
    message: str


class DocumentAttachmentCreateBadRequestIssue(BaseModel):
    message: str


class DocumentAttachmentCreateBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentAttachmentCreateBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentAttachmentCreateBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: DocumentAttachmentCreateBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentAttachmentCreateBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentAttachmentCreateResponseTypedDict(TypedDict):
    r"""Successful response"""

    id: str


class DocumentAttachmentCreateResponse(BaseModel):
    r"""Successful response"""

    id: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from documenso_sdk.utils import FieldMetadata, PathParamMetadata
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import Any, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class RecipientGetTemplateRecipientRequestTypedDict(TypedDict):
    recipient_id: float


class RecipientGetTemplateRecipientRequest(BaseModel):
    recipient_id: Annotated[
        float,
        pydantic.Field(alias="recipientId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class RecipientGetTemplateRecipientInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class RecipientGetTemplateRecipientInternalServerErrorIssue(BaseModel):
    message: str


class RecipientGetTemplateRecipientInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientGetTemplateRecipientInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientGetTemplateRecipientInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: RecipientGetTemplateRecipientInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientGetTemplateRecipientInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientGetTemplateRecipientNotFoundIssueTypedDict(TypedDict):
    message: str


class RecipientGetTemplateRecipientNotFoundIssue(BaseModel):
    message: str


class RecipientGetTemplateRecipientNotFoundErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientGetTemplateRecipientNotFoundIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientGetTemplateRecipientNotFoundError(DocumensoError):
    r"""Not found"""

    data: RecipientGetTemplateRecipientNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientGetTemplateRecipientNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientGetTemplateRecipientForbiddenIssueTypedDict(TypedDict):
    message: str


class RecipientGetTemplateRecipientForbiddenIssue(BaseModel):
    message: str


class RecipientGetTemplateRecipientForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientGetTemplateRecipientForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientGetTemplateRecipientForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: RecipientGetTemplateRecipientForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientGetTemplateRecipientForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientGetTemplateRecipientUnauthorizedIssueTypedDict(TypedDict):
    message: str


class RecipientGetTemplateRecipientUnauthorizedIssue(BaseModel):
    message: str


class RecipientGetTemplateRecipientUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientGetTemplateRecipientUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientGetTemplateRecipientUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: RecipientGetTemplateRecipientUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientGetTemplateRecipientUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientGetTemplateRecipientBadRequestIssueTypedDict(TypedDict):
    message: str


class RecipientGetTemplateRecipientBadRequestIssue(BaseModel):
    message: str


class RecipientGetTemplateRecipientBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientGetTemplateRecipientBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientGetTemplateRecipientBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: RecipientGetTemplateRecipientBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientGetTemplateRecipientBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientGetTemplateRecipientRole(str, Enum):
    CC = "CC"
    SIGNER = "SIGNER"
    VIEWER = "VIEWER"
    APPROVER = "APPROVER"
    ASSISTANT = "ASSISTANT"


class RecipientGetTemplateRecipientReadStatus(str, Enum):
    NOT_OPENED = "NOT_OPENED"
    OPENED = "OPENED"


class RecipientGetTemplateRecipientSigningStatus(str, Enum):
    NOT_SIGNED = "NOT_SIGNED"
    SIGNED = "SIGNED"
    REJECTED = "REJECTED"


class RecipientGetTemplateRecipientSendStatus(str, Enum):
    NOT_SENT = "NOT_SENT"
    SENT = "SENT"


class RecipientGetTemplateRecipientAccessAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class RecipientGetTemplateRecipientActionAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"
    EXPLICIT_NONE = "EXPLICIT_NONE"


class RecipientGetTemplateRecipientAuthOptionsTypedDict(TypedDict):
    access_auth: List[RecipientGetTemplateRecipientAccessAuth]
    action_auth: List[RecipientGetTemplateRecipientActionAuth]


class RecipientGetTemplateRecipientAuthOptions(BaseModel):
    access_auth: Annotated[
        List[RecipientGetTemplateRecipientAccessAuth],
        pydantic.Field(alias="accessAuth"),
    ]

    action_auth: Annotated[
        List[RecipientGetTemplateRecipientActionAuth],
        pydantic.Field(alias="actionAuth"),
    ]


class RecipientGetTemplateRecipientType(str, Enum):
    SIGNATURE = "SIGNATURE"
    FREE_SIGNATURE = "FREE_SIGNATURE"
    INITIALS = "INITIALS"
    NAME = "NAME"
    EMAIL = "EMAIL"
    DATE = "DATE"
    TEXT = "TEXT"
    NUMBER = "NUMBER"
    RADIO = "RADIO"
    CHECKBOX = "CHECKBOX"
    DROPDOWN = "DROPDOWN"


class RecipientGetTemplateRecipientTypeDropdown(str, Enum):
    DROPDOWN = "dropdown"


class RecipientGetTemplateRecipientValue3TypedDict(TypedDict):
    value: str


class RecipientGetTemplateRecipientValue3(BaseModel):
    value: str


class RecipientGetTemplateRecipientFieldMetaDropdownTypedDict(TypedDict):
    type: RecipientGetTemplateRecipientTypeDropdown
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[RecipientGetTemplateRecipientValue3TypedDict]]
    default_value: NotRequired[str]


class RecipientGetTemplateRecipientFieldMetaDropdown(BaseModel):
    type: RecipientGetTemplateRecipientTypeDropdown

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[RecipientGetTemplateRecipientValue3]] = None

    default_value: Annotated[Optional[str], pydantic.Field(alias="defaultValue")] = None


class RecipientGetTemplateRecipientTypeCheckbox(str, Enum):
    CHECKBOX = "checkbox"


class RecipientGetTemplateRecipientValue2TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class RecipientGetTemplateRecipientValue2(BaseModel):
    id: float

    checked: bool

    value: str


class RecipientGetTemplateRecipientDirection2(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class RecipientGetTemplateRecipientFieldMetaCheckboxTypedDict(TypedDict):
    type: RecipientGetTemplateRecipientTypeCheckbox
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[RecipientGetTemplateRecipientValue2TypedDict]]
    validation_rule: NotRequired[str]
    validation_length: NotRequired[float]
    direction: NotRequired[RecipientGetTemplateRecipientDirection2]


class RecipientGetTemplateRecipientFieldMetaCheckbox(BaseModel):
    type: RecipientGetTemplateRecipientTypeCheckbox

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[RecipientGetTemplateRecipientValue2]] = None

    validation_rule: Annotated[
        Optional[str], pydantic.Field(alias="validationRule")
    ] = None

    validation_length: Annotated[
        Optional[float], pydantic.Field(alias="validationLength")
    ] = None

    direction: Optional[RecipientGetTemplateRecipientDirection2] = (
        RecipientGetTemplateRecipientDirection2.VERTICAL
    )


class RecipientGetTemplateRecipientTypeRadio(str, Enum):
    RADIO = "radio"


class RecipientGetTemplateRecipientValue1TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class RecipientGetTemplateRecipientValue1(BaseModel):
    id: float

    checked: bool

    value: str


class RecipientGetTemplateRecipientDirection1(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class RecipientGetTemplateRecipientFieldMetaRadioTypedDict(TypedDict):
    type: RecipientGetTemplateRecipientTypeRadio
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[RecipientGetTemplateRecipientValue1TypedDict]]
    direction: NotRequired[RecipientGetTemplateRecipientDirection1]


class RecipientGetTemplateRecipientFieldMetaRadio(BaseModel):
    type: RecipientGetTemplateRecipientTypeRadio

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[RecipientGetTemplateRecipientValue1]] = None

    direction: Optional[RecipientGetTemplateRecipientDirection1] = (
        RecipientGetTemplateRecipientDirection1.VERTICAL
    )


class RecipientGetTemplateRecipientTypeNumber(str, Enum):
    NUMBER = "number"


class RecipientGetTemplateRecipientTextAlign6(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientGetTemplateRecipientVerticalAlign2(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class RecipientGetTemplateRecipientFieldMetaNumberTypedDict(TypedDict):
    type: RecipientGetTemplateRecipientTypeNumber
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    number_format: NotRequired[Nullable[str]]
    value: NotRequired[str]
    min_value: NotRequired[Nullable[float]]
    max_value: NotRequired[Nullable[float]]
    text_align: NotRequired[RecipientGetTemplateRecipientTextAlign6]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[RecipientGetTemplateRecipientVerticalAlign2]]


class RecipientGetTemplateRecipientFieldMetaNumber(BaseModel):
    type: RecipientGetTemplateRecipientTypeNumber

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    number_format: Annotated[
        OptionalNullable[str], pydantic.Field(alias="numberFormat")
    ] = UNSET

    value: Optional[str] = None

    min_value: Annotated[OptionalNullable[float], pydantic.Field(alias="minValue")] = (
        UNSET
    )

    max_value: Annotated[OptionalNullable[float], pydantic.Field(alias="maxValue")] = (
        UNSET
    )

    text_align: Annotated[
        Optional[RecipientGetTemplateRecipientTextAlign6],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[RecipientGetTemplateRecipientVerticalAlign2],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "numberFormat",
            "value",
            "minValue",
            "maxValue",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = [
            "numberFormat",
            "minValue",
            "maxValue",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class RecipientGetTemplateRecipientTypeText(str, Enum):
    TEXT = "text"


class RecipientGetTemplateRecipientTextAlign5(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientGetTemplateRecipientVerticalAlign1(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class RecipientGetTemplateRecipientFieldMetaTextTypedDict(TypedDict):
    type: RecipientGetTemplateRecipientTypeText
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text: NotRequired[str]
    character_limit: NotRequired[float]
    text_align: NotRequired[RecipientGetTemplateRecipientTextAlign5]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[RecipientGetTemplateRecipientVerticalAlign1]]


class RecipientGetTemplateRecipientFieldMetaText(BaseModel):
    type: RecipientGetTemplateRecipientTypeText

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text: Optional[str] = None

    character_limit: Annotated[
        Optional[float], pydantic.Field(alias="characterLimit")
    ] = None

    text_align: Annotated[
        Optional[RecipientGetTemplateRecipientTextAlign5],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[RecipientGetTemplateRecipientVerticalAlign1],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "text",
            "characterLimit",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = ["lineHeight", "letterSpacing", "verticalAlign"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class RecipientGetTemplateRecipientTypeDate(str, Enum):
    DATE = "date"


class RecipientGetTemplateRecipientTextAlign4(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientGetTemplateRecipientFieldMetaDateTypedDict(TypedDict):
    type: RecipientGetTemplateRecipientTypeDate
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[RecipientGetTemplateRecipientTextAlign4]


class RecipientGetTemplateRecipientFieldMetaDate(BaseModel):
    type: RecipientGetTemplateRecipientTypeDate

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[RecipientGetTemplateRecipientTextAlign4],
        pydantic.Field(alias="textAlign"),
    ] = None


class RecipientGetTemplateRecipientTypeEmail(str, Enum):
    EMAIL = "email"


class RecipientGetTemplateRecipientTextAlign3(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientGetTemplateRecipientFieldMetaEmailTypedDict(TypedDict):
    type: RecipientGetTemplateRecipientTypeEmail
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[RecipientGetTemplateRecipientTextAlign3]


class RecipientGetTemplateRecipientFieldMetaEmail(BaseModel):
    type: RecipientGetTemplateRecipientTypeEmail

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[RecipientGetTemplateRecipientTextAlign3],
        pydantic.Field(alias="textAlign"),
    ] = None


class RecipientGetTemplateRecipientTypeName(str, Enum):
    NAME = "name"


class RecipientGetTemplateRecipientTextAlign2(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientGetTemplateRecipientFieldMetaNameTypedDict(TypedDict):
    type: RecipientGetTemplateRecipientTypeName
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[RecipientGetTemplateRecipientTextAlign2]


class RecipientGetTemplateRecipientFieldMetaName(BaseModel):
    type: RecipientGetTemplateRecipientTypeName

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[RecipientGetTemplateRecipientTextAlign2],
        pydantic.Field(alias="textAlign"),
    ] = None


class RecipientGetTemplateRecipientTypeInitials(str, Enum):
    INITIALS = "initials"


class RecipientGetTemplateRecipientTextAlign1(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientGetTemplateRecipientFieldMetaInitialsTypedDict(TypedDict):
    type: RecipientGetTemplateRecipientTypeInitials
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[RecipientGetTemplateRecipientTextAlign1]


class RecipientGetTemplateRecipientFieldMetaInitials(BaseModel):
    type: RecipientGetTemplateRecipientTypeInitials

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[RecipientGetTemplateRecipientTextAlign1],
        pydantic.Field(alias="textAlign"),
    ] = None


class RecipientGetTemplateRecipientTypeSignature(str, Enum):
    SIGNATURE = "signature"


class RecipientGetTemplateRecipientFieldMetaSignatureTypedDict(TypedDict):
    type: RecipientGetTemplateRecipientTypeSignature
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]


class RecipientGetTemplateRecipientFieldMetaSignature(BaseModel):
    type: RecipientGetTemplateRecipientTypeSignature

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12


RecipientGetTemplateRecipientFieldMetaUnionTypedDict = TypeAliasType(
    "RecipientGetTemplateRecipientFieldMetaUnionTypedDict",
    Union[
        RecipientGetTemplateRecipientFieldMetaSignatureTypedDict,
        RecipientGetTemplateRecipientFieldMetaInitialsTypedDict,
        RecipientGetTemplateRecipientFieldMetaNameTypedDict,
        RecipientGetTemplateRecipientFieldMetaEmailTypedDict,
        RecipientGetTemplateRecipientFieldMetaDateTypedDict,
        RecipientGetTemplateRecipientFieldMetaRadioTypedDict,
        RecipientGetTemplateRecipientFieldMetaDropdownTypedDict,
        RecipientGetTemplateRecipientFieldMetaCheckboxTypedDict,
        RecipientGetTemplateRecipientFieldMetaTextTypedDict,
        RecipientGetTemplateRecipientFieldMetaNumberTypedDict,
    ],
)


RecipientGetTemplateRecipientFieldMetaUnion = TypeAliasType(
    "RecipientGetTemplateRecipientFieldMetaUnion",
    Union[
        RecipientGetTemplateRecipientFieldMetaSignature,
        RecipientGetTemplateRecipientFieldMetaInitials,
        RecipientGetTemplateRecipientFieldMetaName,
        RecipientGetTemplateRecipientFieldMetaEmail,
        RecipientGetTemplateRecipientFieldMetaDate,
        RecipientGetTemplateRecipientFieldMetaRadio,
        RecipientGetTemplateRecipientFieldMetaDropdown,
        RecipientGetTemplateRecipientFieldMetaCheckbox,
        RecipientGetTemplateRecipientFieldMetaText,
        RecipientGetTemplateRecipientFieldMetaNumber,
    ],
)


class RecipientGetTemplateRecipientFieldTypedDict(TypedDict):
    envelope_id: str
    envelope_item_id: str
    type: RecipientGetTemplateRecipientType
    id: float
    secondary_id: str
    recipient_id: float
    page: float
    position_x: Any
    position_y: Any
    width: Any
    height: Any
    custom_text: str
    inserted: bool
    field_meta: Nullable[RecipientGetTemplateRecipientFieldMetaUnionTypedDict]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class RecipientGetTemplateRecipientField(BaseModel):
    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    envelope_item_id: Annotated[str, pydantic.Field(alias="envelopeItemId")]

    type: RecipientGetTemplateRecipientType

    id: float

    secondary_id: Annotated[str, pydantic.Field(alias="secondaryId")]

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page: float

    position_x: Annotated[Any, pydantic.Field(alias="positionX")]

    position_y: Annotated[Any, pydantic.Field(alias="positionY")]

    width: Any

    height: Any

    custom_text: Annotated[str, pydantic.Field(alias="customText")]

    inserted: bool

    field_meta: Annotated[
        Nullable[RecipientGetTemplateRecipientFieldMetaUnion],
        pydantic.Field(alias="fieldMeta"),
    ]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = ["fieldMeta", "documentId", "templateId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class RecipientGetTemplateRecipientResponseTypedDict(TypedDict):
    r"""Successful response"""

    envelope_id: str
    role: RecipientGetTemplateRecipientRole
    read_status: RecipientGetTemplateRecipientReadStatus
    signing_status: RecipientGetTemplateRecipientSigningStatus
    send_status: RecipientGetTemplateRecipientSendStatus
    id: float
    email: str
    name: str
    token: str
    document_deleted_at: Nullable[str]
    expired: Nullable[str]
    signed_at: Nullable[str]
    auth_options: Nullable[RecipientGetTemplateRecipientAuthOptionsTypedDict]
    signing_order: Nullable[float]
    rejection_reason: Nullable[str]
    fields: List[RecipientGetTemplateRecipientFieldTypedDict]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class RecipientGetTemplateRecipientResponse(BaseModel):
    r"""Successful response"""

    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    role: RecipientGetTemplateRecipientRole

    read_status: Annotated[
        RecipientGetTemplateRecipientReadStatus, pydantic.Field(alias="readStatus")
    ]

    signing_status: Annotated[
        RecipientGetTemplateRecipientSigningStatus,
        pydantic.Field(alias="signingStatus"),
    ]

    send_status: Annotated[
        RecipientGetTemplateRecipientSendStatus, pydantic.Field(alias="sendStatus")
    ]

    id: float

    email: str

    name: str

    token: str

    document_deleted_at: Annotated[
        Nullable[str], pydantic.Field(alias="documentDeletedAt")
    ]

    expired: Nullable[str]

    signed_at: Annotated[Nullable[str], pydantic.Field(alias="signedAt")]

    auth_options: Annotated[
        Nullable[RecipientGetTemplateRecipientAuthOptions],
        pydantic.Field(alias="authOptions"),
    ]

    signing_order: Annotated[Nullable[float], pydantic.Field(alias="signingOrder")]

    rejection_reason: Annotated[Nullable[str], pydantic.Field(alias="rejectionReason")]

    fields: List[RecipientGetTemplateRecipientField]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = [
            "documentDeletedAt",
            "expired",
            "signedAt",
            "authOptions",
            "signingOrder",
            "rejectionReason",
            "documentId",
            "templateId",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from documenso_sdk.utils import FieldMetadata, PathParamMetadata
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import Any, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class RecipientGetDocumentRecipientRequestTypedDict(TypedDict):
    recipient_id: float


class RecipientGetDocumentRecipientRequest(BaseModel):
    recipient_id: Annotated[
        float,
        pydantic.Field(alias="recipientId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class RecipientGetDocumentRecipientInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class RecipientGetDocumentRecipientInternalServerErrorIssue(BaseModel):
    message: str


class RecipientGetDocumentRecipientInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientGetDocumentRecipientInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientGetDocumentRecipientInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: RecipientGetDocumentRecipientInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientGetDocumentRecipientInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientGetDocumentRecipientNotFoundIssueTypedDict(TypedDict):
    message: str


class RecipientGetDocumentRecipientNotFoundIssue(BaseModel):
    message: str


class RecipientGetDocumentRecipientNotFoundErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientGetDocumentRecipientNotFoundIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientGetDocumentRecipientNotFoundError(DocumensoError):
    r"""Not found"""

    data: RecipientGetDocumentRecipientNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientGetDocumentRecipientNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientGetDocumentRecipientForbiddenIssueTypedDict(TypedDict):
    message: str


class RecipientGetDocumentRecipientForbiddenIssue(BaseModel):
    message: str


class RecipientGetDocumentRecipientForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientGetDocumentRecipientForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientGetDocumentRecipientForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: RecipientGetDocumentRecipientForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientGetDocumentRecipientForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientGetDocumentRecipientUnauthorizedIssueTypedDict(TypedDict):
    message: str


class RecipientGetDocumentRecipientUnauthorizedIssue(BaseModel):
    message: str


class RecipientGetDocumentRecipientUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientGetDocumentRecipientUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientGetDocumentRecipientUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: RecipientGetDocumentRecipientUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientGetDocumentRecipientUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientGetDocumentRecipientBadRequestIssueTypedDict(TypedDict):
    message: str


class RecipientGetDocumentRecipientBadRequestIssue(BaseModel):
    message: str


class RecipientGetDocumentRecipientBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientGetDocumentRecipientBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientGetDocumentRecipientBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: RecipientGetDocumentRecipientBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientGetDocumentRecipientBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientGetDocumentRecipientRole(str, Enum):
    CC = "CC"
    SIGNER = "SIGNER"
    VIEWER = "VIEWER"
    APPROVER = "APPROVER"
    ASSISTANT = "ASSISTANT"


class RecipientGetDocumentRecipientReadStatus(str, Enum):
    NOT_OPENED = "NOT_OPENED"
    OPENED = "OPENED"


class RecipientGetDocumentRecipientSigningStatus(str, Enum):
    NOT_SIGNED = "NOT_SIGNED"
    SIGNED = "SIGNED"
    REJECTED = "REJECTED"


class RecipientGetDocumentRecipientSendStatus(str, Enum):
    NOT_SENT = "NOT_SENT"
    SENT = "SENT"


class RecipientGetDocumentRecipientAccessAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class RecipientGetDocumentRecipientActionAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"
    EXPLICIT_NONE = "EXPLICIT_NONE"


class RecipientGetDocumentRecipientAuthOptionsTypedDict(TypedDict):
    access_auth: List[RecipientGetDocumentRecipientAccessAuth]
    action_auth: List[RecipientGetDocumentRecipientActionAuth]


class RecipientGetDocumentRecipientAuthOptions(BaseModel):
    access_auth: Annotated[
        List[RecipientGetDocumentRecipientAccessAuth],
        pydantic.Field(alias="accessAuth"),
    ]

    action_auth: Annotated[
        List[RecipientGetDocumentRecipientActionAuth],
        pydantic.Field(alias="actionAuth"),
    ]


class RecipientGetDocumentRecipientType(str, Enum):
    SIGNATURE = "SIGNATURE"
    FREE_SIGNATURE = "FREE_SIGNATURE"
    INITIALS = "INITIALS"
    NAME = "NAME"
    EMAIL = "EMAIL"
    DATE = "DATE"
    TEXT = "TEXT"
    NUMBER = "NUMBER"
    RADIO = "RADIO"
    CHECKBOX = "CHECKBOX"
    DROPDOWN = "DROPDOWN"


class RecipientGetDocumentRecipientTypeDropdown(str, Enum):
    DROPDOWN = "dropdown"


class RecipientGetDocumentRecipientValue3TypedDict(TypedDict):
    value: str


class RecipientGetDocumentRecipientValue3(BaseModel):
    value: str


class RecipientGetDocumentRecipientFieldMetaDropdownTypedDict(TypedDict):
    type: RecipientGetDocumentRecipientTypeDropdown
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[RecipientGetDocumentRecipientValue3TypedDict]]
    default_value: NotRequired[str]


class RecipientGetDocumentRecipientFieldMetaDropdown(BaseModel):
    type: RecipientGetDocumentRecipientTypeDropdown

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[RecipientGetDocumentRecipientValue3]] = None

    default_value: Annotated[Optional[str], pydantic.Field(alias="defaultValue")] = None


class RecipientGetDocumentRecipientTypeCheckbox(str, Enum):
    CHECKBOX = "checkbox"


class RecipientGetDocumentRecipientValue2TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class RecipientGetDocumentRecipientValue2(BaseModel):
    id: float

    checked: bool

    value: str


class RecipientGetDocumentRecipientDirection2(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class RecipientGetDocumentRecipientFieldMetaCheckboxTypedDict(TypedDict):
    type: RecipientGetDocumentRecipientTypeCheckbox
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[RecipientGetDocumentRecipientValue2TypedDict]]
    validation_rule: NotRequired[str]
    validation_length: NotRequired[float]
    direction: NotRequired[RecipientGetDocumentRecipientDirection2]


class RecipientGetDocumentRecipientFieldMetaCheckbox(BaseModel):
    type: RecipientGetDocumentRecipientTypeCheckbox

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[RecipientGetDocumentRecipientValue2]] = None

    validation_rule: Annotated[
        Optional[str], pydantic.Field(alias="validationRule")
    ] = None

    validation_length: Annotated[
        Optional[float], pydantic.Field(alias="validationLength")
    ] = None

    direction: Optional[RecipientGetDocumentRecipientDirection2] = (
        RecipientGetDocumentRecipientDirection2.VERTICAL
    )


class RecipientGetDocumentRecipientTypeRadio(str, Enum):
    RADIO = "radio"


class RecipientGetDocumentRecipientValue1TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class RecipientGetDocumentRecipientValue1(BaseModel):
    id: float

    checked: bool

    value: str


class RecipientGetDocumentRecipientDirection1(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class RecipientGetDocumentRecipientFieldMetaRadioTypedDict(TypedDict):
    type: RecipientGetDocumentRecipientTypeRadio
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[RecipientGetDocumentRecipientValue1TypedDict]]
    direction: NotRequired[RecipientGetDocumentRecipientDirection1]


class RecipientGetDocumentRecipientFieldMetaRadio(BaseModel):
    type: RecipientGetDocumentRecipientTypeRadio

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[RecipientGetDocumentRecipientValue1]] = None

    direction: Optional[RecipientGetDocumentRecipientDirection1] = (
        RecipientGetDocumentRecipientDirection1.VERTICAL
    )


class RecipientGetDocumentRecipientTypeNumber(str, Enum):
    NUMBER = "number"


class RecipientGetDocumentRecipientTextAlign6(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientGetDocumentRecipientVerticalAlign2(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class RecipientGetDocumentRecipientFieldMetaNumberTypedDict(TypedDict):
    type: RecipientGetDocumentRecipientTypeNumber
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    number_format: NotRequired[Nullable[str]]
    value: NotRequired[str]
    min_value: NotRequired[Nullable[float]]
    max_value: NotRequired[Nullable[float]]
    text_align: NotRequired[RecipientGetDocumentRecipientTextAlign6]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[RecipientGetDocumentRecipientVerticalAlign2]]


class RecipientGetDocumentRecipientFieldMetaNumber(BaseModel):
    type: RecipientGetDocumentRecipientTypeNumber

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    number_format: Annotated[
        OptionalNullable[str], pydantic.Field(alias="numberFormat")
    ] = UNSET

    value: Optional[str] = None

    min_value: Annotated[OptionalNullable[float], pydantic.Field(alias="minValue")] = (
        UNSET
    )

    max_value: Annotated[OptionalNullable[float], pydantic.Field(alias="maxValue")] = (
        UNSET
    )

    text_align: Annotated[
        Optional[RecipientGetDocumentRecipientTextAlign6],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[RecipientGetDocumentRecipientVerticalAlign2],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "numberFormat",
            "value",
            "minValue",
            "maxValue",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = [
            "numberFormat",
            "minValue",
            "maxValue",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class RecipientGetDocumentRecipientTypeText(str, Enum):
    TEXT = "text"


class RecipientGetDocumentRecipientTextAlign5(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientGetDocumentRecipientVerticalAlign1(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class RecipientGetDocumentRecipientFieldMetaTextTypedDict(TypedDict):
    type: RecipientGetDocumentRecipientTypeText
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text: NotRequired[str]
    character_limit: NotRequired[float]
    text_align: NotRequired[RecipientGetDocumentRecipientTextAlign5]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[RecipientGetDocumentRecipientVerticalAlign1]]


class RecipientGetDocumentRecipientFieldMetaText(BaseModel):
    type: RecipientGetDocumentRecipientTypeText

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text: Optional[str] = None

    character_limit: Annotated[
        Optional[float], pydantic.Field(alias="characterLimit")
    ] = None

    text_align: Annotated[
        Optional[RecipientGetDocumentRecipientTextAlign5],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[RecipientGetDocumentRecipientVerticalAlign1],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "text",
            "characterLimit",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = ["lineHeight", "letterSpacing", "verticalAlign"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class RecipientGetDocumentRecipientTypeDate(str, Enum):
    DATE = "date"


class RecipientGetDocumentRecipientTextAlign4(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientGetDocumentRecipientFieldMetaDateTypedDict(TypedDict):
    type: RecipientGetDocumentRecipientTypeDate
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[RecipientGetDocumentRecipientTextAlign4]


class RecipientGetDocumentRecipientFieldMetaDate(BaseModel):
    type: RecipientGetDocumentRecipientTypeDate

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[RecipientGetDocumentRecipientTextAlign4],
        pydantic.Field(alias="textAlign"),
    ] = None


class RecipientGetDocumentRecipientTypeEmail(str, Enum):
    EMAIL = "email"


class RecipientGetDocumentRecipientTextAlign3(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientGetDocumentRecipientFieldMetaEmailTypedDict(TypedDict):
    type: RecipientGetDocumentRecipientTypeEmail
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[RecipientGetDocumentRecipientTextAlign3]


class RecipientGetDocumentRecipientFieldMetaEmail(BaseModel):
    type: RecipientGetDocumentRecipientTypeEmail

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[RecipientGetDocumentRecipientTextAlign3],
        pydantic.Field(alias="textAlign"),
    ] = None


class RecipientGetDocumentRecipientTypeName(str, Enum):
    NAME = "name"


class RecipientGetDocumentRecipientTextAlign2(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientGetDocumentRecipientFieldMetaNameTypedDict(TypedDict):
    type: RecipientGetDocumentRecipientTypeName
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[RecipientGetDocumentRecipientTextAlign2]


class RecipientGetDocumentRecipientFieldMetaName(BaseModel):
    type: RecipientGetDocumentRecipientTypeName

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[RecipientGetDocumentRecipientTextAlign2],
        pydantic.Field(alias="textAlign"),
    ] = None


class RecipientGetDocumentRecipientTypeInitials(str, Enum):
    INITIALS = "initials"


class RecipientGetDocumentRecipientTextAlign1(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class RecipientGetDocumentRecipientFieldMetaInitialsTypedDict(TypedDict):
    type: RecipientGetDocumentRecipientTypeInitials
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[RecipientGetDocumentRecipientTextAlign1]


class RecipientGetDocumentRecipientFieldMetaInitials(BaseModel):
    type: RecipientGetDocumentRecipientTypeInitials

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[RecipientGetDocumentRecipientTextAlign1],
        pydantic.Field(alias="textAlign"),
    ] = None


class RecipientGetDocumentRecipientTypeSignature(str, Enum):
    SIGNATURE = "signature"


class RecipientGetDocumentRecipientFieldMetaSignatureTypedDict(TypedDict):
    type: RecipientGetDocumentRecipientTypeSignature
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]


class RecipientGetDocumentRecipientFieldMetaSignature(BaseModel):
    type: RecipientGetDocumentRecipientTypeSignature

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12


RecipientGetDocumentRecipientFieldMetaUnionTypedDict = TypeAliasType(
    "RecipientGetDocumentRecipientFieldMetaUnionTypedDict",
    Union[
        RecipientGetDocumentRecipientFieldMetaSignatureTypedDict,
        RecipientGetDocumentRecipientFieldMetaInitialsTypedDict,
        RecipientGetDocumentRecipientFieldMetaNameTypedDict,
        RecipientGetDocumentRecipientFieldMetaEmailTypedDict,
        RecipientGetDocumentRecipientFieldMetaDateTypedDict,
        RecipientGetDocumentRecipientFieldMetaRadioTypedDict,
        RecipientGetDocumentRecipientFieldMetaDropdownTypedDict,
        RecipientGetDocumentRecipientFieldMetaCheckboxTypedDict,
        RecipientGetDocumentRecipientFieldMetaTextTypedDict,
        RecipientGetDocumentRecipientFieldMetaNumberTypedDict,
    ],
)


RecipientGetDocumentRecipientFieldMetaUnion = TypeAliasType(
    "RecipientGetDocumentRecipientFieldMetaUnion",
    Union[
        RecipientGetDocumentRecipientFieldMetaSignature,
        RecipientGetDocumentRecipientFieldMetaInitials,
        RecipientGetDocumentRecipientFieldMetaName,
        RecipientGetDocumentRecipientFieldMetaEmail,
        RecipientGetDocumentRecipientFieldMetaDate,
        RecipientGetDocumentRecipientFieldMetaRadio,
        RecipientGetDocumentRecipientFieldMetaDropdown,
        RecipientGetDocumentRecipientFieldMetaCheckbox,
        RecipientGetDocumentRecipientFieldMetaText,
        RecipientGetDocumentRecipientFieldMetaNumber,
    ],
)


class RecipientGetDocumentRecipientFieldTypedDict(TypedDict):
    envelope_id: str
    envelope_item_id: str
    type: RecipientGetDocumentRecipientType
    id: float
    secondary_id: str
    recipient_id: float
    page: float
    position_x: Any
    position_y: Any
    width: Any
    height: Any
    custom_text: str
    inserted: bool
    field_meta: Nullable[RecipientGetDocumentRecipientFieldMetaUnionTypedDict]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class RecipientGetDocumentRecipientField(BaseModel):
    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    envelope_item_id: Annotated[str, pydantic.Field(alias="envelopeItemId")]

    type: RecipientGetDocumentRecipientType

    id: float

    secondary_id: Annotated[str, pydantic.Field(alias="secondaryId")]

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page: float

    position_x: Annotated[Any, pydantic.Field(alias="positionX")]

    position_y: Annotated[Any, pydantic.Field(alias="positionY")]

    width: Any

    height: Any

    custom_text: Annotated[str, pydantic.Field(alias="customText")]

    inserted: bool

    field_meta: Annotated[
        Nullable[RecipientGetDocumentRecipientFieldMetaUnion],
        pydantic.Field(alias="fieldMeta"),
    ]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = ["fieldMeta", "documentId", "templateId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class RecipientGetDocumentRecipientResponseTypedDict(TypedDict):
    r"""Successful response"""

    envelope_id: str
    role: RecipientGetDocumentRecipientRole
    read_status: RecipientGetDocumentRecipientReadStatus
    signing_status: RecipientGetDocumentRecipientSigningStatus
    send_status: RecipientGetDocumentRecipientSendStatus
    id: float
    email: str
    name: str
    token: str
    document_deleted_at: Nullable[str]
    expired: Nullable[str]
    signed_at: Nullable[str]
    auth_options: Nullable[RecipientGetDocumentRecipientAuthOptionsTypedDict]
    signing_order: Nullable[float]
    rejection_reason: Nullable[str]
    fields: List[RecipientGetDocumentRecipientFieldTypedDict]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class RecipientGetDocumentRecipientResponse(BaseModel):
    r"""Successful response"""

    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    role: RecipientGetDocumentRecipientRole

    read_status: Annotated[
        RecipientGetDocumentRecipientReadStatus, pydantic.Field(alias="readStatus")
    ]

    signing_status: Annotated[
        RecipientGetDocumentRecipientSigningStatus,
        pydantic.Field(alias="signingStatus"),
    ]

    send_status: Annotated[
        RecipientGetDocumentRecipientSendStatus, pydantic.Field(alias="sendStatus")
    ]

    id: float

    email: str

    name: str

    token: str

    document_deleted_at: Annotated[
        Nullable[str], pydantic.Field(alias="documentDeletedAt")
    ]

    expired: Nullable[str]

    signed_at: Annotated[Nullable[str], pydantic.Field(alias="signedAt")]

    auth_options: Annotated[
        Nullable[RecipientGetDocumentRecipientAuthOptions],
        pydantic.Field(alias="authOptions"),
    ]

    signing_order: Annotated[Nullable[float], pydantic.Field(alias="signingOrder")]

    rejection_reason: Annotated[Nullable[str], pydantic.Field(alias="rejectionReason")]

    fields: List[RecipientGetDocumentRecipientField]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = [
            "documentDeletedAt",
            "expired",
            "signedAt",
            "authOptions",
            "signingOrder",
            "rejectionReason",
            "documentId",
            "templateId",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import Dict, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class DocumentDistributeDateFormat(str, Enum):
    YYYY_M_MDD_HH_MM_A = "yyyy-MM-dd hh:mm a"
    YYYY_M_MDD = "yyyy-MM-dd"
    DD_MM_SLASH_YYYY = "dd/MM/yyyy"
    MM_DD_SLASH_YYYY = "MM/dd/yyyy"
    YY_M_MDD = "yy-MM-dd"
    MMMM_DD_COMMA_YYYY = "MMMM dd, yyyy"
    EEEE_MMMM_DD_COMMA_YYYY = "EEEE, MMMM dd, yyyy"
    DD_MM_SLASH_YYYY_HH_MM_A = "dd/MM/yyyy hh:mm a"
    DD_MM_SLASH_YYYY_H_HMM = "dd/MM/yyyy HH:mm"
    MM_DD_SLASH_YYYY_HH_MM_A = "MM/dd/yyyy hh:mm a"
    MM_DD_SLASH_YYYY_H_HMM = "MM/dd/yyyy HH:mm"
    DD_DOT_MM_DOT_YYYY = "dd.MM.yyyy"
    DD_DOT_MM_DOT_YYYY_H_HMM = "dd.MM.yyyy HH:mm"
    YYYY_M_MDD_H_HMM = "yyyy-MM-dd HH:mm"
    YY_M_MDD_HH_MM_A = "yy-MM-dd hh:mm a"
    YY_M_MDD_H_HMM = "yy-MM-dd HH:mm"
    YYYY_M_MDD_H_HMMSS = "yyyy-MM-dd HH:mm:ss"
    MMMM_DD_COMMA_YYYY_HH_MM_A = "MMMM dd, yyyy hh:mm a"
    MMMM_DD_COMMA_YYYY_H_HMM = "MMMM dd, yyyy HH:mm"
    EEEE_MMMM_DD_COMMA_YYYY_HH_MM_A = "EEEE, MMMM dd, yyyy hh:mm a"
    EEEE_MMMM_DD_COMMA_YYYY_H_HMM = "EEEE, MMMM dd, yyyy HH:mm"
    ISO8601_FULL = "yyyy-MM-dd'T'HH:mm:ss.SSSXXX"


class DocumentDistributeDistributionMethod(str, Enum):
    EMAIL = "EMAIL"
    NONE = "NONE"


class DocumentDistributeLanguage(str, Enum):
    DE = "de"
    EN = "en"
    FR = "fr"
    ES = "es"
    IT = "it"
    PL = "pl"


class DocumentDistributeEmailSettingsTypedDict(TypedDict):
    recipient_signing_request: NotRequired[bool]
    recipient_removed: NotRequired[bool]
    recipient_signed: NotRequired[bool]
    document_pending: NotRequired[bool]
    document_completed: NotRequired[bool]
    document_deleted: NotRequired[bool]
    owner_document_completed: NotRequired[bool]


class DocumentDistributeEmailSettings(BaseModel):
    recipient_signing_request: Annotated[
        Optional[bool], pydantic.Field(alias="recipientSigningRequest")
    ] = True

    recipient_removed: Annotated[
        Optional[bool], pydantic.Field(alias="recipientRemoved")
    ] = True

    recipient_signed: Annotated[
        Optional[bool], pydantic.Field(alias="recipientSigned")
    ] = True

    document_pending: Annotated[
        Optional[bool], pydantic.Field(alias="documentPending")
    ] = True

    document_completed: Annotated[
        Optional[bool], pydantic.Field(alias="documentCompleted")
    ] = True

    document_deleted: Annotated[
        Optional[bool], pydantic.Field(alias="documentDeleted")
    ] = True

    owner_document_completed: Annotated[
        Optional[bool], pydantic.Field(alias="ownerDocumentCompleted")
    ] = True


class DocumentDistributeMetaTypedDict(TypedDict):
    subject: NotRequired[str]
    message: NotRequired[str]
    timezone: NotRequired[str]
    date_format: NotRequired[DocumentDistributeDateFormat]
    distribution_method: NotRequired[DocumentDistributeDistributionMethod]
    redirect_url: NotRequired[str]
    language: NotRequired[DocumentDistributeLanguage]
    email_id: NotRequired[Nullable[str]]
    email_reply_to: NotRequired[Nullable[str]]
    email_settings: NotRequired[DocumentDistributeEmailSettingsTypedDict]


class DocumentDistributeMeta(BaseModel):
    subject: Optional[str] = None

    message: Optional[str] = None

    timezone: Optional[str] = None

    date_format: Annotated[
        Optional[DocumentDistributeDateFormat], pydantic.Field(alias="dateFormat")
    ] = None

    distribution_method: Annotated[
        Optional[DocumentDistributeDistributionMethod],
        pydantic.Field(alias="distributionMethod"),
    ] = None

    redirect_url: Annotated[Optional[str], pydantic.Field(alias="redirectUrl")] = None

    language: Optional[DocumentDistributeLanguage] = None

    email_id: Annotated[OptionalNullable[str], pydantic.Field(alias="emailId")] = UNSET

    email_reply_to: Annotated[
        OptionalNullable[str], pydantic.Field(alias="emailReplyTo")
    ] = UNSET

    email_settings: Annotated[
        Optional[DocumentDistributeEmailSettings], pydantic.Field(alias="emailSettings")
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "subject",
            "message",
            "timezone",
            "dateFormat",
            "distributionMethod",
            "redirectUrl",
            "language",
            "emailId",
            "emailReplyTo",
            "emailSettings",
        ]
        nullable_fields = ["emailId", "emailReplyTo"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class DocumentDistributeRequestTypedDict(TypedDict):
    document_id: float
    meta: NotRequired[DocumentDistributeMetaTypedDict]


class DocumentDistributeRequest(BaseModel):
    document_id: Annotated[float, pydantic.Field(alias="documentId")]

    meta: Optional[DocumentDistributeMeta] = None


class DocumentDistributeInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class DocumentDistributeInternalServerErrorIssue(BaseModel):
    message: str


class DocumentDistributeInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDistributeInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDistributeInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: DocumentDistributeInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDistributeInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDistributeForbiddenIssueTypedDict(TypedDict):
    message: str


class DocumentDistributeForbiddenIssue(BaseModel):
    message: str


class DocumentDistributeForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDistributeForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDistributeForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: DocumentDistributeForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDistributeForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDistributeUnauthorizedIssueTypedDict(TypedDict):
    message: str


class DocumentDistributeUnauthorizedIssue(BaseModel):
    message: str


class DocumentDistributeUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDistributeUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDistributeUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: DocumentDistributeUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDistributeUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDistributeBadRequestIssueTypedDict(TypedDict):
    message: str


class DocumentDistributeBadRequestIssue(BaseModel):
    message: str


class DocumentDistributeBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDistributeBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDistributeBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: DocumentDistributeBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDistributeBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDistributeVisibility(str, Enum):
    EVERYONE = "EVERYONE"
    MANAGER_AND_ABOVE = "MANAGER_AND_ABOVE"
    ADMIN = "ADMIN"


class DocumentDistributeStatus(str, Enum):
    DRAFT = "DRAFT"
    PENDING = "PENDING"
    COMPLETED = "COMPLETED"
    REJECTED = "REJECTED"


class DocumentDistributeSource(str, Enum):
    DOCUMENT = "DOCUMENT"
    TEMPLATE = "TEMPLATE"
    TEMPLATE_DIRECT_LINK = "TEMPLATE_DIRECT_LINK"


class DocumentDistributeGlobalAccessAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class DocumentDistributeGlobalActionAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"


class DocumentDistributeAuthOptionsTypedDict(TypedDict):
    global_access_auth: List[DocumentDistributeGlobalAccessAuth]
    global_action_auth: List[DocumentDistributeGlobalActionAuth]


class DocumentDistributeAuthOptions(BaseModel):
    global_access_auth: Annotated[
        List[DocumentDistributeGlobalAccessAuth],
        pydantic.Field(alias="globalAccessAuth"),
    ]

    global_action_auth: Annotated[
        List[DocumentDistributeGlobalActionAuth],
        pydantic.Field(alias="globalActionAuth"),
    ]


DocumentDistributeFormValuesTypedDict = TypeAliasType(
    "DocumentDistributeFormValuesTypedDict", Union[str, bool, float]
)


DocumentDistributeFormValues = TypeAliasType(
    "DocumentDistributeFormValues", Union[str, bool, float]
)


class DocumentDistributeResponseTypedDict(TypedDict):
    r"""Successful response"""

    visibility: DocumentDistributeVisibility
    status: DocumentDistributeStatus
    source: DocumentDistributeSource
    id: float
    external_id: Nullable[str]
    user_id: float
    auth_options: Nullable[DocumentDistributeAuthOptionsTypedDict]
    form_values: Nullable[Dict[str, DocumentDistributeFormValuesTypedDict]]
    title: str
    created_at: str
    updated_at: str
    completed_at: Nullable[str]
    deleted_at: Nullable[str]
    team_id: float
    folder_id: Nullable[str]
    use_legacy_field_insertion: bool
    envelope_id: str
    internal_version: float
    document_data_id: NotRequired[str]
    template_id: NotRequired[Nullable[float]]


class DocumentDistributeResponse(BaseModel):
    r"""Successful response"""

    visibility: DocumentDistributeVisibility

    status: DocumentDistributeStatus

    source: DocumentDistributeSource

    id: float

    external_id: Annotated[Nullable[str], pydantic.Field(alias="externalId")]

    user_id: Annotated[float, pydantic.Field(alias="userId")]

    auth_options: Annotated[
        Nullable[DocumentDistributeAuthOptions], pydantic.Field(alias="authOptions")
    ]

    form_values: Annotated[
        Nullable[Dict[str, DocumentDistributeFormValues]],
        pydantic.Field(alias="formValues"),
    ]

    title: str

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]

    updated_at: Annotated[str, pydantic.Field(alias="updatedAt")]

    completed_at: Annotated[Nullable[str], pydantic.Field(alias="completedAt")]

    deleted_at: Annotated[Nullable[str], pydantic.Field(alias="deletedAt")]

    team_id: Annotated[float, pydantic.Field(alias="teamId")]

    folder_id: Annotated[Nullable[str], pydantic.Field(alias="folderId")]

    use_legacy_field_insertion: Annotated[
        bool, pydantic.Field(alias="useLegacyFieldInsertion")
    ]

    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    internal_version: Annotated[float, pydantic.Field(alias="internalVersion")]

    document_data_id: Annotated[
        Optional[str], pydantic.Field(alias="documentDataId")
    ] = ""

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentDataId", "templateId"]
        nullable_fields = [
            "externalId",
            "authOptions",
            "formValues",
            "completedAt",
            "deletedAt",
            "folderId",
            "templateId",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel
import httpx
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, TypedDict


class EnvelopeFieldDeleteRequestTypedDict(TypedDict):
    field_id: float


class EnvelopeFieldDeleteRequest(BaseModel):
    field_id: Annotated[float, pydantic.Field(alias="fieldId")]


class EnvelopeFieldDeleteInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class EnvelopeFieldDeleteInternalServerErrorIssue(BaseModel):
    message: str


class EnvelopeFieldDeleteInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeFieldDeleteInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeFieldDeleteInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: EnvelopeFieldDeleteInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeFieldDeleteInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeFieldDeleteForbiddenIssueTypedDict(TypedDict):
    message: str


class EnvelopeFieldDeleteForbiddenIssue(BaseModel):
    message: str


class EnvelopeFieldDeleteForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeFieldDeleteForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeFieldDeleteForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: EnvelopeFieldDeleteForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeFieldDeleteForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeFieldDeleteUnauthorizedIssueTypedDict(TypedDict):
    message: str


class EnvelopeFieldDeleteUnauthorizedIssue(BaseModel):
    message: str


class EnvelopeFieldDeleteUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeFieldDeleteUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeFieldDeleteUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: EnvelopeFieldDeleteUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeFieldDeleteUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeFieldDeleteBadRequestIssueTypedDict(TypedDict):
    message: str


class EnvelopeFieldDeleteBadRequestIssue(BaseModel):
    message: str


class EnvelopeFieldDeleteBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeFieldDeleteBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeFieldDeleteBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: EnvelopeFieldDeleteBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeFieldDeleteBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeFieldDeleteResponseTypedDict(TypedDict):
    r"""Successful response"""

    success: bool


class EnvelopeFieldDeleteResponse(BaseModel):
    r"""Successful response"""

    success: bool



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel
import httpx
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, TypedDict


class DocumentDeleteRequestTypedDict(TypedDict):
    document_id: float


class DocumentDeleteRequest(BaseModel):
    document_id: Annotated[float, pydantic.Field(alias="documentId")]


class DocumentDeleteInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class DocumentDeleteInternalServerErrorIssue(BaseModel):
    message: str


class DocumentDeleteInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDeleteInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDeleteInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: DocumentDeleteInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDeleteInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDeleteForbiddenIssueTypedDict(TypedDict):
    message: str


class DocumentDeleteForbiddenIssue(BaseModel):
    message: str


class DocumentDeleteForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDeleteForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDeleteForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: DocumentDeleteForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDeleteForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDeleteUnauthorizedIssueTypedDict(TypedDict):
    message: str


class DocumentDeleteUnauthorizedIssue(BaseModel):
    message: str


class DocumentDeleteUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDeleteUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDeleteUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: DocumentDeleteUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDeleteUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDeleteBadRequestIssueTypedDict(TypedDict):
    message: str


class DocumentDeleteBadRequestIssue(BaseModel):
    message: str


class DocumentDeleteBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDeleteBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDeleteBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: DocumentDeleteBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDeleteBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDeleteResponseTypedDict(TypedDict):
    r"""Successful response"""

    success: bool


class DocumentDeleteResponse(BaseModel):
    r"""Successful response"""

    success: bool
